@@ -1,5 +1,6 @@
 from pathlib import Path
 
+from pyrrhic.repo.index import Index
 from pyrrhic.repo.pack import Pack
 from pyrrhic.repo.repository import Repository, get_masterkey
 
@@ -22,15 +23,11 @@ def test_load_pack(masterkey):
 
 def test_index_matches_packs(masterkey):
     repo = Repository(Path(REPO_BASE) / "restic_test_repository", masterkey)
-    indexes = repo.get_index(INDEX_ID)
-    index = next(indexes, None)
-    assert index
-    assert next(indexes, None) is None
-
-    for index_pack in index.packs:
+    index = repo.get_index(INDEX_ID)
+    assert type(index) == Index
+    for index_pack in index.index:
         p = Pack(repo.repository, masterkey, index_pack.id)
         for index_blob in index_pack.blobs:
-            print("Checking ", index_blob.id)
             pack_blobs = p.get_blob_index()
             assert (matching_blob := next((blob for blob in pack_blobs if blob["id"] == index_blob.id)))
             assert matching_blob["offset"] == index_blob.offset
